Welcome to Yampy
================

Yampy (pronounced "Yam Pie") is a Python wrapper for Yammer's RESTful API.

See the :ref:`quickstart_guide` for information on getting up and running
quickly. You'll find details in the :ref:`api_documentation`.  If you want to
contribute to Yampy, please read the :ref:`contributing_guide` first.

Contents
--------

.. toctree::
   :maxdepth: 2

   quickstart
   api
   contributing

Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`
